
Usage
=====

active_layer
------------
  .. literalinclude:: ../examples/active_layer.py

add_slate
---------
  .. literalinclude:: ../examples/add_slate.py

apply_filters
-------------
  .. literalinclude:: ../examples/apply_filters.py

color
-----
  .. literalinclude:: ../examples/color.py

compare_colors
--------------
  .. literalinclude:: ../examples/compare_colors.py

copy_and_paste
--------------
  .. literalinclude:: ../examples/copy_and_paste.py

create_thumbnail
----------------
  .. literalinclude:: ../examples/create_thumbnail.py

emboss_action
-------------
  .. literalinclude:: ../examples/emboss_action.py

eval_javascript
---------------
  .. literalinclude:: ../examples/eval_javascript.py

hello_world
-----------
  .. literalinclude:: ../examples/hello_world.py

link_layer
----------
  .. literalinclude:: ../examples/link_layer.py

move_to_end
-----------
  .. literalinclude:: ../examples/move_to_end.py

new_document
------------
  .. literalinclude:: ../examples/new_document.py

open_psd
--------
  .. literalinclude:: ../examples/open_psd.py

rotate_layer
------------
  .. literalinclude:: ../examples/rotate_layer.py

selection_stroke
----------------
  .. literalinclude:: ../examples/selection_stroke.py

set_active_layer
----------------
  .. literalinclude:: ../examples/set_active_layer.py

smart_sharpen
-------------
  .. literalinclude:: ../examples/smart_sharpen.py

    